@@ -41,6 +41,11 @@ class Container(Component):
         return cp
 
 
+class MarkdownBoxContainer(Container):
+    def __init__(self) -> None:
+        super().__init__('markdown-box')
+
+
 class BoxContainer(Container):
     def __init__(self, sepc=0) -> None:
         super().__init__('box')
@@ -188,11 +193,19 @@ class BoxContainer(Container):
     def markdown(self, md: str, **prop_mapping: TypePropInfo):
         layout = MarkdownLayout(md, prop_mapping)
 
+        box = self.__markdown_box()
+
         for cp in layout.parse_markdown():
             self._on_before_add_child_fn(cp)
-            self.add_child(cp)
+            box.add_child(cp)
         return layout
 
+    def __markdown_box(self):
+        cp = MarkdownBoxContainer()
+        self._on_before_add_child_fn(cp)
+        self.add_child(cp)
+        return cp
+
     @property
     def isHover(self):
         p = self.get_prop('isHover')
