@@ -28,8 +28,11 @@ class MethodPropInfo(AbsPropInfo):
 
 
 class LambdaMethodPropInfo(AbsPropInfo):
-    def __init__(self, value: AbsPropInfo) -> None:
-        super().__init__(FnsValuator('()=>'), None)
+    def __init__(self, value: AbsPropInfo,args:Optional[List[str]]=None) -> None:
+
+        var = f"({','.join(args or [])})=>"
+
+        super().__init__(FnsValuator(var), None)
         self.value = value
 
     def _ex_gen_expr(self):
